@@ -404,7 +404,7 @@ def MakeProfiles(ClustersFileName="VicinityPermissiveClustsLinear" + "RM_A" + ".
             pool.join()
 
 
-    if __name__ == os.path.relpath(__file__).split('.')[0]:
+    if __name__ == __name__:
         t1 = time.time()
         cnt = 0
 
@@ -1093,7 +1093,7 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./", PathTo
         reduce_known_pos.to_csv(outname,index= False)
         
         
-    if __name__ == os.path.relpath(__file__).split('.')[0]:
+    if __name__ == __name__:
         filename = Relevance_CategoryName
         outname = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/output_Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
         binary_cls_analysis(filename, outname)
